@@ -103,9 +103,6 @@ void OctaveExpression::parseOutput ( QString output )
     {
         if (command().contains(QLatin1String("help")))
         {
-            //Escape whitespace
-            m_resultString.replace( QLatin1Char(' '), QLatin1String("&nbsp;"));
-
             setResult(new Cantor::HelpResult(m_resultString));
         }
         else
@@ -152,7 +149,8 @@ void OctaveExpression::finalize()
     qDebug() << "finalize: " << m_resultString;
     foreach ( const QString& line, m_resultString.split(QLatin1Char('\n'), QString::SkipEmptyParts) )
     {
-        if (m_resultString.contains(QLatin1Char('=')))
+        if ((m_resultString.contains(QLatin1Char('='))) && !(command().startsWith(QLatin1String("help(")))
+                && !(command().contains(QLatin1String("help "))) && !(command().contains(QLatin1String("type("))))
         {
             qDebug() << line;
             // Probably a new variable
